package com.sun.beans.editors;

import java.awt.Component;
import java.awt.Rectangle;
import java.awt.Graphics;
import java.beans.PropertyChangeEvent;
import java.util.ArrayList;
import java.beans.PropertyChangeListener;
import java.util.List;
import java.beans.PropertyEditor;

public final class EnumEditor implements PropertyEditor
{
    private final List<PropertyChangeListener> listeners;
    private final Class type;
    private final String[] tags;
    private Object value;
    
    public EnumEditor(Class clazz) {
        this.listeners = new ArrayList();
        Object[] enumConstants = clazz.getEnumConstants();
        if (enumConstants == null) {
            throw new IllegalArgumentException("Unsupported " + clazz);
        }
        this.type = clazz;
        this.tags = new String[enumConstants.length];
        for (int i = 0; i < enumConstants.length; ++i) {
            this.tags[i] = ((Enum)enumConstants[i]).name();
        }
        return;
    }
    
    @Override
    public Object getValue() {
        return this.value;
    }
    
    @Override
    public void setValue(Object obj) {
        if (obj != null && !this.type.isInstance(obj)) {
            throw new IllegalArgumentException("Unsupported value: " + obj);
        }
        Object value;
        PropertyChangeListener[] array;
        Label_0135: {
            synchronized (this.listeners) {
                value = this.value;
                this.value = obj;
                if ((obj != null) ? (!obj.equals(value)) : (value != null)) {
                    int size = this.listeners.size();
                    if (size == 0) {
                        return;
                    }
                    array = (PropertyChangeListener[])this.listeners.toArray(new PropertyChangeListener[size]);
                    break Label_0135;
                }
                return;
            }
        }
        PropertyChangeEvent propertyChangeEvent = new PropertyChangeEvent(this, null, value, obj);
        for (int length = array.length, i = 0; i < length; ++i) {
            array[i].propertyChange(propertyChangeEvent);
        }
        return;
    }
    
    @Override
    public String getAsText() {
        return (this.value != null) ? ((Enum)this.value).name() : null;
    }
    
    @Override
    public void setAsText(String name) {
        this.setValue((name != null) ? Enum.valueOf(this.type, name) : null);
    }
    
    @Override
    public String[] getTags() {
        return (String[])this.tags.clone();
    }
    
    @Override
    public String getJavaInitializationString() {
        String asText = this.getAsText();
        return (asText != null) ? (this.type.getName() + 46 + asText) : "null";
    }
    
    @Override
    public boolean isPaintable() {
        return false;
    }
    
    @Override
    public void paintValue(Graphics graphics, Rectangle rectangle) {
    }
    
    @Override
    public boolean supportsCustomEditor() {
        return false;
    }
    
    @Override
    public Component getCustomEditor() {
        return null;
    }
    
    @Override
    public void addPropertyChangeListener(PropertyChangeListener propertyChangeListener) {
        synchronized (this.listeners) {
            this.listeners.add(propertyChangeListener);
        }
    }
    
    @Override
    public void removePropertyChangeListener(PropertyChangeListener propertyChangeListener) {
        synchronized (this.listeners) {
            this.listeners.remove(propertyChangeListener);
        }
    }
}
